@@ -25,7 +25,7 @@ class AsxDecoder final : public IPlaylistDecoder
 public:
 	virtual ~AsxDecoder() = default;
 
-	bool is_url_direct_stream(const std::string& /*url*/) { return false; };
+	bool is_url_direct_stream(const std::string& /*url*/, const std::string& /*content_type*/) { return false; };
 
 	bool is_decodable(const std::string& content_type, const std::string& content);
 
