@@ -26,7 +26,7 @@ class RamDecoder final : public M3uDecoder
 public:
 	virtual ~RamDecoder() = default;
 
-	bool is_url_direct_stream(const std::string& /*url*/) { return false; };
+	bool is_url_direct_stream(const std::string& /*url*/, const std::string& /*content_type*/) { return false; };
 
 	bool is_decodable(const std::string& content_type, const std::string& content);
 
